@@ -185,26 +185,6 @@ void drawWithoutReplacementFisherYates(std::vector<size_t>& result, std::mt19937
   result.resize(num_samples);
 }
 
-void drawWithoutReplacementWeighted(std::vector<size_t>& result, std::mt19937_64& random_number_generator,
-    const std::vector<size_t>& indices, size_t num_samples, const std::vector<double>& weights) {
-
-  result.reserve(num_samples);
-
-  // Set all to not selected
-  std::vector<bool> temp;
-  temp.resize(indices.size(), false);
-
-  std::discrete_distribution<> weighted_dist(weights.begin(), weights.end());
-  for (size_t i = 0; i < num_samples; ++i) {
-    size_t draw;
-    do {
-      draw = weighted_dist(random_number_generator);
-    } while (temp[draw]);
-    temp[draw] = true;
-    result.push_back(indices[draw]);
-  }
-}
-
 void drawWithoutReplacementWeighted(std::vector<size_t>& result, std::mt19937_64& random_number_generator,
     size_t max_index, size_t num_samples, const std::vector<double>& weights) {
 
